/*
Author: Daniel Jones
IDE: VSCodium
Browsers tested: Firefox 124
Last change: 04/08/24
purpose: portfolio website to show to potential freelance customers/web developer positions
*/


import { PointLight } from 'three';
import './style.css';
import {OrbitControls} from 'three/examples/jsm/controls/OrbitControls';
import * as THREE from 'three';



const scene = new THREE.Scene();




const camera = new THREE.PerspectiveCamera(75, window.innerWidth / window.innerHeight, 0.1, 1000);

const renderer = new THREE.WebGLRenderer({
    canvas: document.querySelector('#bg'),
});

renderer.setPixelRatio(window.devicePixelRatio);
renderer.setSize(window.innerWidth, window.innerHeight);
camera.position.setZ(30);

renderer.render(scene, camera);



const pointLight = new PointLight(0xffffff, 150);

const ambientLight = new THREE.AmbientLight(0xffffff);
scene.add(ambientLight, pointLight);

pointLight.position.set(10, 10, 10);

const lightHelper = new THREE.PointLightHelper(pointLight);


const gridHelper = new THREE.GridHelper(200, 50);
scene.add(gridHelper, lightHelper);

const controls = new OrbitControls(camera, renderer.domElement);


//beggining of creating floor 
const floorTexture = new THREE.TextureLoader().load("marble.jpg");
floorTexture.wrapT = THREE.RepeatWrapping;
floorTexture.wrapS = THREE.RepeatWrapping;
floorTexture.repeat.set(1, 10);
const floorGeometry = new THREE.PlaneGeometry(100, 1000, 1000, 1000);
const floorMaterial = new THREE.MeshStandardMaterial({
    map: floorTexture,
})
const floor = new THREE.Mesh(floorGeometry, floorMaterial);
floor.rotateX(200);
scene.add(floor);



function animate(){
    requestAnimationFrame(animate);

    renderer.render(scene, camera)
}
animate();
